summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authormichelou <michelou@epfl.ch>2006-11-29 13:11:31 +0000
committermichelou <michelou@epfl.ch>2006-11-29 13:11:31 +0000
commitf9da023c4e7d57e38ba0041e0ee31b9ee46ec4a9 (patch)
tree46e7bc64451aec5325e0d06a671cd5b549ab29fd /src
parent50c411759b491a88d7ffca8fcda9bce9d22ac22c (diff)
downloadscala-f9da023c4e7d57e38ba0041e0ee31b9ee46ec4a9.tar.gz
scala-f9da023c4e7d57e38ba0041e0ee31b9ee46ec4a9.tar.bz2
scala-f9da023c4e7d57e38ba0041e0ee31b9ee46ec4a9.zip
renamed directory 'resident' to match '--res' o...
renamed directory 'resident' to match '--res' option
Diffstat (limited to 'src')
-rw-r--r--src/compiler/scala/tools/nsc/doc/DocGenerator.scala10
1 files changed, 7 insertions, 3 deletions
diff --git a/src/compiler/scala/tools/nsc/doc/DocGenerator.scala b/src/compiler/scala/tools/nsc/doc/DocGenerator.scala
index 9c66dc59eb..c749c922da 100644
--- a/src/compiler/scala/tools/nsc/doc/DocGenerator.scala
+++ b/src/compiler/scala/tools/nsc/doc/DocGenerator.scala
@@ -989,7 +989,10 @@ abstract class DocGenerator extends Models {
* </p>
*/"""
}
- def numericValDescr(sym: Symbol) = """
+ def numericValDescr(sym: Symbol) = {
+ val maxValue = "MAX_" + sym.name.toString().toUpperCase()
+ val minValue = "MIN_" + sym.name.toString().toUpperCase();
+ """
/** <p>
* Class <code>""" + sym.name + """ </code> belongs to the value
* classes whose instances are not represented as objects by the
@@ -997,10 +1000,11 @@ abstract class DocGenerator extends Models {
* <a href="AnyVal.html"><code>AnyVal</code></a>.
* </p>
* <p>
* Value <code>MAX_""" + sym.name.toString().toUpperCase() + """</code>
* in defined in object <a href="compat/Math$object.html">scala.compat.Math</a>.
* </p>
*/"""
+ }
new PrimitiveContentFrame {
def sym = definitions.ByteClass
def descr = numericValDescr(sym)
@@ -997,10 +1000,11 @@ abstract class DocGenerator extends Models {
* </p>
* <p>
- * Value <code>MAX_""" + sym.name.toString().toUpperCase() + """</code>
- * in defined in object <a href="compat/Math$object.html">scala.compat.Math</a>.
+ * Values <code>""" + maxValue + """</code> and <code>""" + minValue + """</code>
+ * are in defined in object <a href="compat/Math$object.html">scala.compat.Math</a>.
* </p>
*/"""